@@ -1,285 +1,311 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="fi" version="2.1">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="fi">
 <context>
     <name>MXDateTime</name>
     <message>
-        <location filename="datetime.ui" line="20"/>
-        <location filename="datetime.cpp" line="596"/>
+        <location filename="../datetime.ui" line="20"/>
+        <location filename="../datetime.cpp" line="604"/>
         <source>MX Date &amp; Time</source>
         <translation>MX päivämäärä &amp; kellonaika</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="26"/>
+        <location filename="../datetime.ui" line="26"/>
         <source>Close</source>
         <translation>Sulje</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="40"/>
+        <location filename="../datetime.ui" line="40"/>
         <source>Help</source>
         <translation>Ohje</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="73"/>
+        <location filename="../datetime.ui" line="73"/>
         <source>Apply</source>
         <translation>Hyväksy</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="100"/>
+        <location filename="../datetime.ui" line="100"/>
         <source>About...</source>
         <translation>Tietoja...</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="124"/>
+        <location filename="../datetime.ui" line="124"/>
         <source>Date &amp;&amp; Time</source>
         <translation>Päivämäärä &amp;&amp; kellonaika</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="192"/>
+        <location filename="../datetime.ui" line="192"/>
         <source>H:mm:ss</source>
         <translation>t:mm:ss</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="278"/>
-        <location filename="datetime.cpp" line="296"/>
-        <location filename="datetime.cpp" line="303"/>
+        <location filename="../datetime.ui" line="278"/>
+        <location filename="../datetime.cpp" line="298"/>
+        <location filename="../datetime.cpp" line="305"/>
         <source>Hardware Clock</source>
         <translation>Laitteistokellonaika</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="284"/>
+        <location filename="../datetime.ui" line="284"/>
         <source>Hardware Clock tools</source>
         <translation>Työkalut laitteistokellolle</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="290"/>
+        <location filename="../datetime.ui" line="290"/>
         <source>Obtain information from the Hardware Clock and present it in the box below.</source>
         <translation>Nouda tietoja laitteistokellosta ja esitä ne allaolevassa laatikossa.</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="293"/>
+        <location filename="../datetime.ui" line="293"/>
         <source>Read the Hardware Clock</source>
         <translation>Lue laitteistokellonaika</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="300"/>
+        <location filename="../datetime.ui" line="303"/>
         <source>Apply systematic drift corrections to the Hardware Clock.</source>
         <translation>Toteuta järjestelmälliset kasautumakorjaukset laitteistokelloon.</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="303"/>
+        <location filename="../datetime.ui" line="306"/>
         <source>Drift Adjust</source>
         <translation>Kasautumien säätö</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="323"/>
+        <location filename="../datetime.ui" line="329"/>
         <source>Time transfer</source>
         <translation>Kellonajan siirto</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="329"/>
+        <location filename="../datetime.ui" line="335"/>
         <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
         <translation>Aseta järjestelmäkello täsmäämään tämänhetkisen ajan kanssa välittömästi suhteessa laitteistokelloon. </translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="332"/>
+        <location filename="../datetime.ui" line="338"/>
         <source>Hardware Clock to System Clock</source>
         <translation>Laitteistokellosta järjestelmäkelloon</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="339"/>
+        <location filename="../datetime.ui" line="348"/>
         <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
         <translation>Aseta laitteistokello täsmäämään tämänhetkisen ajan kanssa välittömästi suhteessa järjestelmäkelloon.</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="342"/>
+        <location filename="../datetime.ui" line="351"/>
         <source>System Clock to Hardware Clock</source>
         <translation>Järjestelmäkellosta laitteistokelloon</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="349"/>
+        <location filename="../datetime.ui" line="361"/>
         <source>Update the drift factor for the Hardware Clock when it is being set.</source>
         <translation>Päivitä laitteistokellon kasautumamääre asetettaessa.</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="352"/>
+        <location filename="../datetime.ui" line="364"/>
         <source>Update the drift</source>
         <translation>Päivitä kasautuma</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="362"/>
+        <location filename="../datetime.ui" line="374"/>
         <source>Time zone for the Hardware Clock</source>
         <translation>Laitteistokellon aikavyöhyke</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="368"/>
+        <location filename="../datetime.ui" line="380"/>
         <source>Local time</source>
         <translation>Paikallinen aika</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="371"/>
+        <location filename="../datetime.ui" line="383"/>
         <source>Local</source>
         <translation>Paikallinen</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="378"/>
+        <location filename="../datetime.ui" line="390"/>
         <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
         <translation>Koordinoitu yleisaika UCT (tai GMT Greenwich Meridian Time)</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="381"/>
+        <location filename="../datetime.ui" line="393"/>
         <source>UTC</source>
         <translation>UTC</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="421"/>
+        <location filename="../datetime.ui" line="433"/>
         <source>Network Time</source>
         <translation>Verkon kellonaika</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="427"/>
+        <location filename="../datetime.ui" line="439"/>
         <source>Move the selected item down</source>
         <translation>Siirrä valittua kohdetta alas</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="438"/>
+        <location filename="../datetime.ui" line="450"/>
         <source>Move the selected item up</source>
         <translation>Siirrä valittua kohdetta ylös</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="449"/>
+        <location filename="../datetime.ui" line="461"/>
         <source>Remove the current item from the list</source>
         <translation>Poista tämänhetkinen kohde luettelosta</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="460"/>
+        <location filename="../datetime.ui" line="472"/>
         <source>Add an item to the list</source>
         <translation>Lisää kohde luetteloon</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="486"/>
+        <location filename="../datetime.ui" line="498"/>
         <source>Automatically update the System Clock with NTP servers:</source>
         <translation>Päivitä järjestelmäkello NTP-palvelimien kanssa automaattisesti:</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="493"/>
+        <location filename="../datetime.ui" line="505"/>
         <source>Immediately update the system clock with NTP servers.</source>
         <translation>Päivitä järjestelmäkello NTP-palvelimien kanssa välittömästi:</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="496"/>
+        <location filename="../datetime.ui" line="508"/>
         <source>Update Now</source>
         <translation>Päivitä heti</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="505"/>
+        <location filename="../datetime.ui" line="520"/>
         <source>List of NTP servers to use.</source>
         <translation>Käytettävissä olevien NTP-palvelimien luettelo.</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="521"/>
+        <location filename="../datetime.ui" line="536"/>
         <source>Type</source>
         <translation>Tyyppi</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="526"/>
+        <location filename="../datetime.ui" line="541"/>
         <source>Address</source>
         <translation>Osoite</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="531"/>
+        <location filename="../datetime.ui" line="546"/>
         <source>Options</source>
         <translation>Asetukset</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="270"/>
+        <location filename="../datetime.cpp" line="272"/>
         <source>Reading...</source>
         <translation>Lukee...</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="284"/>
+        <location filename="../datetime.cpp" line="286"/>
         <source>Adjusting...</source>
         <translation>Mukauttaa...</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="296"/>
-        <location filename="datetime.cpp" line="303"/>
+        <location filename="../datetime.cpp" line="298"/>
+        <location filename="../datetime.cpp" line="305"/>
         <source>System Clock</source>
         <translation>Järjestelmäkello</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="309"/>
+        <location filename="../datetime.cpp" line="311"/>
         <source>The %1 time was transferred to the %2.</source>
         <translation>%1 aika siirrettiin %2 :een.</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="312"/>
+        <location filename="../datetime.cpp" line="314"/>
         <source>The %1 time could not be transferred to the %2.</source>
         <translation>%1 aikaa ei voitu siirtää %2 :een</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="350"/>
+        <location filename="../datetime.cpp" line="354"/>
         <source>Updating...</source>
         <translation>Päivittää...</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="360"/>
+        <location filename="../datetime.cpp" line="367"/>
         <source>The system clock was updated successfully.</source>
         <translation>Järjestelmäkello päivitettiin onnistuneesti.</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="362"/>
+        <location filename="../datetime.cpp" line="369"/>
         <source>The system clock could not be updated.</source>
         <translation>Järjestelmäkelloa ei voitu päivittää.</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="364"/>
+        <location filename="../datetime.cpp" line="371"/>
         <source>None of the NTP servers on the list are currently enabled.</source>
         <translation>Yksikään luettelon NTP-palvelimista ei ole tällä hetkellä päälle kytkettynä.</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="595"/>
+        <location filename="../datetime.cpp" line="604"/>
         <source>About MX Date &amp; Time</source>
         <translation>Tietoja MX:n päivämäärästä &amp; kellonajasta</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="596"/>
+        <location filename="../datetime.cpp" line="605"/>
         <source>Version: </source>
         <translation>Versio: </translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="597"/>
+        <location filename="../datetime.cpp" line="606"/>
         <source>GUI program for setting the time and date in MX Linux</source>
         <translation>Graafinen ohjelma kellonajan ja päivämäärän asettamiseen MX Linux:issa.</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="599"/>
+        <location filename="../datetime.cpp" line="608"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="600"/>
-        <location filename="datetime.cpp" line="614"/>
+        <location filename="../datetime.cpp" line="610"/>
+        <source>%1 License</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>License</source>
-        <translation>Lisenssi</translation>
+        <translation type="vanished">Lisenssi</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="601"/>
         <source>Changelog</source>
-        <translation>Muutosloki</translation>
+        <translation type="vanished">Muutosloki</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="602"/>
         <source>Cancel</source>
-        <translation>Peru</translation>
+        <translation type="vanished">Peru</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="628"/>
         <source>&amp;Close</source>
-        <translation>&amp;Sulje</translation>
+        <translation type="vanished">&amp;Sulje</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="646"/>
+        <location filename="../datetime.cpp" line="616"/>
         <source>MX Date &amp; Time Help</source>
         <translation>MX:n päivämäärän &amp; kellonajan apuopas</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../about.cpp" line="52"/>
+        <source>License</source>
+        <translation type="unfinished">Lisenssi</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="53"/>
+        <location filename="../about.cpp" line="62"/>
+        <source>Changelog</source>
+        <translation type="unfinished">Muutosloki</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="54"/>
+        <source>Cancel</source>
+        <translation type="unfinished">Peru</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="74"/>
+        <source>&amp;Close</source>
+        <translation type="unfinished">&amp;Sulje</translation>
+    </message>
+</context>
+</TS>
